<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=el
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_effacer_statistiques' => 'Delete the statistics', # MODIF

	// I
	'icone_evolution_visites' => 'Επιπεδο επισκέψεων<br />@visites@ επισκέψεις',
	'icone_repartition_actuelle' => 'Εμφάνιση της τωρινής κατανομής',
	'icone_repartition_visites' => 'Κατανομή των επισκέψεων',
	'icone_statistiques_visites' => 'Στατιστικά',
	'info_affichier_visites_articles_plus_visites' => 'Δείξτε τους επισκέπτες σας για <b>τα πιο δημοφιλή σας αρθρα απο την έναρξη:</b>',
	'info_comment_lire_tableau' => 'Πως να διαβάσατε αυτό το γραφικό',
	'info_forum_statistiques' => 'Στατιστικά επισκεπτών',
	'info_visites' => 'Επισκέψεις :',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Manage statistics', # MODIF

	// O
	'onglet_origine_visites' => 'Προέλευση επισκεπτών',
	'onglet_repartition_debut' => 'από την αρχή',
	'onglet_repartition_lang' => 'Κατάταξη ανά γλώσσα',

	// R
	'resume' => 'Resume', # MODIF
];
